[Python-checkins] cpython (merge 3.5 -> default): Merge 3.5

yury.selivanov python-checkins at python.org
Wed Aug 26 19:04:14 CEST 2015


https://hg.python.org/cpython/rev/55fa2fba132c
changeset:   97515:55fa2fba132c
parent:      97513:b66a8240925a
parent:      97514:9f7f6f7145f4
user:        Yury Selivanov <yselivanov at sprymix.com>
date:        Wed Aug 26 13:04:06 2015 -0400
summary:
  Merge 3.5

files:
  Doc/includes/typestruct.h |  3 ++-
  Include/object.h          |  3 ++-
  2 files changed, 4 insertions(+), 2 deletions(-)


diff --git a/Doc/includes/typestruct.h b/Doc/includes/typestruct.h
--- a/Doc/includes/typestruct.h
+++ b/Doc/includes/typestruct.h
@@ -9,7 +9,8 @@
     printfunc tp_print;
     getattrfunc tp_getattr;
     setattrfunc tp_setattr;
-    PyAsyncMethods *tp_as_async; /* formerly known as tp_compare or tp_reserved */
+    PyAsyncMethods *tp_as_async; /* formerly known as tp_compare (Python 2)
+                                    or tp_reserved (Python 3) */
     reprfunc tp_repr;
 
     /* Method suites for standard classes */
diff --git a/Include/object.h b/Include/object.h
--- a/Include/object.h
+++ b/Include/object.h
@@ -351,7 +351,8 @@
     printfunc tp_print;
     getattrfunc tp_getattr;
     setattrfunc tp_setattr;
-    PyAsyncMethods *tp_as_async; /* formerly known as tp_compare or tp_reserved */
+    PyAsyncMethods *tp_as_async; /* formerly known as tp_compare (Python 2)
+                                    or tp_reserved (Python 3) */
     reprfunc tp_repr;
 
     /* Method suites for standard classes */

-- 
Repository URL: https://hg.python.org/cpython


More information about the Python-checkins mailing list